# {{project_name}}

{{project_description}}

## Credits

This project is based on the [Python DevOps template](https://github.com/lrothack/dev-ops) which supports

- code quality monitoring with SonarQube
- testing and deployment in a multi-stage Docker environment
- packaging with setuptools
- code analysis with pylint, bandit, pytest and coverage
- support for additional containerized components (MongoDB, MlFlow)

